@@ -169,6 +169,10 @@ def kind_from_path(path: Path, *, base: bool = False) -> FileType:
     if str(path) == "/dev/stdin":
         return "playbook"
 
+    if path.name == "pattern.json":
+        # This is a pattern file
+        return "pattern"
+
     # Unknown file types report a empty string (evaluated as False)
     return ""
 
@@ -407,7 +411,8 @@ class Lintable:
     def failed(self) -> bool:
         """Return true if we already found syntax-check errors on this file."""
         return any(
-            match.rule.id in ("syntax-check", "load-failure") for match in self.matches
+            match.rule.id in ("syntax-check", "load-failure", "internal-error")
+            for match in self.matches
         )
 
     @property
@@ -435,10 +440,11 @@ class Lintable:
                         from ansiblelint.skip_utils import append_skipped_rules
 
                     # pylint: disable=possibly-used-before-assignment
-                    self.state = append_skipped_rules(
-                        self.state,
-                        self,
-                    )
+                    if self.state:
+                        self.state = append_skipped_rules(
+                            self.state,
+                            self,
+                        )
                 else:
                     _logger.debug(
                         "data set to None for %s due to being '%s' (%s) kind.",
@@ -584,6 +590,7 @@ def get_all_files(
         pathspecs = [
             pathspec.GitIgnoreSpec.from_lines(
                 [
+                    ".ansible",
                     ".git",
                     ".tox",
                     ".mypy_cache",
@@ -610,7 +617,7 @@ def get_all_files(
         else:
             for item in sorted(path.iterdir()):
                 if is_excluded(item):
-                    _logger.info("Excluded: %s", item)
+                    _logger.debug("Excluded: %s", item)
                     continue
                 if item.is_file():
                     all_files.append(item)
