@@ -14,7 +14,9 @@ from typing import TYPE_CHECKING, NamedTuple
 import black
 import jinja2
 from ansible.errors import AnsibleError, AnsibleFilterError, AnsibleParserError
+from ansible_compat.config import ansible_version
 from jinja2.exceptions import TemplateSyntaxError
+from packaging.version import Version
 
 from ansiblelint.errors import RuleMatchTransformMeta
 from ansiblelint.file_utils import Lintable
@@ -67,6 +69,8 @@ ignored_re = re.compile(
             r"^The '(.*)' test expects a dictionary$",
             # https://github.com/ansible/ansible-lint/issues/4338
             r"An unhandled exception occurred while templating (.*). Error was a <class 'ansible.errors.AnsibleFilterError'>, original message: The (.*) test expects a dictionary$",
+            r"can only concatenate list \(not \"_AnsibleTaggedStr\"\) to list",
+            r"can only concatenate str \(not \"_AnsibleTaggedStr\"\) to str",
         ],
     ),
     flags=re.MULTILINE | re.DOTALL,
@@ -145,11 +149,15 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                     except AnsibleFilterError:
                         bypass = True
                     # ValueError RepresenterError
-                    except AnsibleError as exc:
+                    except (AnsibleError, ImportError) as exc:
                         bypass = False
-                        orig_exc = (
-                            exc.orig_exc if getattr(exc, "orig_exc", None) else exc
-                        )
+                        orig_exc: BaseException = exc
+                        if (
+                            isinstance(exc, AnsibleError)
+                            and hasattr(exc, "orig_exc")
+                            and exc.orig_exc
+                        ):
+                            orig_exc = exc.orig_exc
                         orig_exc_message = getattr(orig_exc, "message", str(orig_exc))
                         match = self._ansible_error_re.match(
                             getattr(orig_exc, "message", str(orig_exc)),
@@ -185,14 +193,24 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                                 bypass = True
                             else:
                                 bypass = False
+                        elif isinstance(exc, ImportError):
+                            if self.options and self.options.nodeps:
+                                msg = f"Ignored exception {exc} due to running with nodeps mode."
+                                _logger.debug(msg)
+                                continue
+                            bypass = False
                         elif re.match(r"^lookup plugin (.*) not found$", exc.message):
                             # lookup plugin 'template' not found
                             bypass = True
-                        elif isinstance(
-                            orig_exc, AnsibleTemplateSyntaxError
-                        ) and re.match(
-                            r"^Syntax error in template: No filter named '.*'.",
-                            exc.message,
+                        elif (
+                            exc.message == "A template was resolved to an Omit scalar."
+                            or (
+                                isinstance(orig_exc, AnsibleTemplateSyntaxError)
+                                and re.match(
+                                    r"^Syntax error in template: No filter named '.*'.",
+                                    exc.message,
+                                )
+                            )
                         ):
                             bypass = True
 
@@ -305,7 +323,9 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             )
         return tokens
 
-    def unlex(self, tokens: list[Token]) -> str:
+    def unlex(
+        self, tokens: list[Token], original_line_ending: str | None = None
+    ) -> str:
         """Return original text by compiling the lex output."""
         result = ""
         last_lineno = 1
@@ -316,6 +336,11 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             result += value
             last_lineno = lineno
             last_value = value
+
+        # Preserve original line endings if they were different from \n
+        if original_line_ending and original_line_ending != "\n":
+            result = result.replace("\n", original_line_ending)
+
         return result
 
     # pylint: disable=too-many-locals
@@ -348,6 +373,13 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                 return value
             return value[3:-3]
 
+        # Detect original line ending style to preserve it
+        # Only preserve \r\n (Windows CRLF), let \r (Mac classic) be normalized to \n
+        # as per jinja 3.0.0 behavior (see test case 44)
+        original_line_ending = None
+        if "\r\n" in text:
+            original_line_ending = "\r\n"
+
         tokens = []
         details = ""
         begin_types = ("variable_begin", "comment_begin", "block_begin")
@@ -427,7 +459,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             return uncook(text, implicit=implicit), "", "spacing"
 
         # finalize
-        reformatted = self.unlex(tokens)
+        reformatted = self.unlex(tokens, original_line_ending)
         failed = reformatted != text
         reformatted = uncook(reformatted, implicit=implicit)
         details = (
@@ -518,6 +550,7 @@ if "pytest" in sys.modules:
     from ansiblelint.runner import Runner
     from ansiblelint.transformer import Transformer
 
+    @pytest.mark.libyaml
     def test_jinja_spacing_playbook() -> None:
         """Ensure that expected error lines are matching found linting error lines."""
         # list unexpected error lines or non-matching error lines
@@ -595,9 +628,6 @@ if "pytest" in sys.modules:
             ),
             pytest.param("{{foo(123)}}", "{{ foo(123) }}", "spacing", id="11"),
             pytest.param("{{ foo(a.b.c) }}", "{{ foo(a.b.c) }}", "spacing", id="12"),
-            # pytest.param(
-            #     "spacing",
-            # ),
             pytest.param(
                 "{{foo(x =['server_options'])}}",
                 "{{ foo(x=['server_options']) }}",
@@ -766,6 +796,13 @@ if "pytest" in sys.modules:
                 "spacing",
                 id="45",
             ),
+            # Windows line endings (\r\n) should be preserved, but \r alone should normalize to \n
+            pytest.param(
+                "Created on {{ '%Y-%m-%d %H:%M:%S %Z' | strftime }}.\r\n",
+                "Created on {{ '%Y-%m-%d %H:%M:%S %Z' | strftime }}.\r\n",
+                "spacing",
+                id="46",
+            ),
         ),
     )
     def test_jinja(text: str, expected: str, tag: str) -> None:
@@ -837,10 +874,10 @@ if "pytest" in sys.modules:
         assert len(errs) == 2
         assert errs[0].tag == "jinja[spacing]"
         assert errs[0].rule.id == "jinja"
-        assert errs[0].lineno == 9
+        assert errs[0].lineno in [9, 13]  # ruamel w/ clib return different numbers
         assert errs[1].tag == "jinja[invalid]"
         assert errs[1].rule.id == "jinja"
-        assert errs[1].lineno in [9, 10]  # 2.19 has better line identification
+        assert errs[1].lineno in [9, 10, 13]  # 2.19 has better line identification
 
     def test_jinja_valid() -> None:
         """Tests our ability to parse jinja, even when variables may not be defined."""
@@ -872,12 +909,11 @@ if "pytest" in sys.modules:
 
         orig_content = playbook.read_text(encoding="utf-8")
         expected_content = playbook.with_suffix(
-            f".transformed{playbook.suffix}",
+            f".transformed{playbook.suffix}"
         ).read_text(encoding="utf-8")
         transformed_content = playbook.with_suffix(f".tmp{playbook.suffix}").read_text(
-            encoding="utf-8",
+            encoding="utf-8"
         )
-
         assert orig_content != transformed_content
         assert expected_content == transformed_content
         playbook.with_suffix(f".tmp{playbook.suffix}").unlink()
@@ -889,10 +925,10 @@ if "pytest" in sys.modules:
             data = args[1]
 
             if data != "{{ 12 | random(seed=inventory_hostname) }}":
-                return do_template(*args, **kwargs)  # type: ignore[no-untyped-call]
+                return do_template(*args, **kwargs)
 
             msg = "Unexpected templating type error occurred on (foo): bar"
-            raise AnsibleError(str(msg))  # type: ignore[no-untyped-call]
+            raise AnsibleError(str(msg))
 
         do_template = Templar.do_template
         collection = RulesCollection()
@@ -901,3 +937,47 @@ if "pytest" in sys.modules:
         with mock.patch.object(Templar, "do_template", _do_template):
             results = Runner(lintable, rules=collection).run()
             assert len(results) == 0
+
+    @pytest.mark.parametrize(
+        ("nodeps", "expected_results"),
+        (
+            pytest.param(
+                "0",
+                0 if ansible_version() >= Version("2.19.0.dev0") else 1,
+                id="normal",
+            ),
+            pytest.param("1", 0, id="nodeps"),
+        ),
+    )
+    def test_filter_import_failure(
+        nodeps: str, expected_results: int, monkeypatch: pytest.MonkeyPatch
+    ) -> None:
+        """Tests how we process import failures from within filters."""
+        monkeypatch.setenv("ANSIBLE_LINT_NODEPS", nodeps)
+        collection = RulesCollection()
+        collection.register(JinjaRule())
+        lintable = Lintable("examples/playbooks/test_filter_with_importerror.yml")
+        results = Runner(lintable, rules=collection).run()
+        assert len(results) == expected_results
+
+    def test_jinja_template_generates_ansible_tagged_str_error() -> None:
+        """Test that demonstrates ansible-core generating _AnsibleTaggedStr errors and us ignoring them."""
+        # Test the ignore pattern directly without full RulesCollection setup
+        from ansiblelint.rules.jinja import ignored_re
+
+        # Test _AnsibleTaggedStr error is ignored
+        tagged_error_msg = 'can only concatenate list (not "_AnsibleTaggedStr") to list'
+        assert ignored_re.search(tagged_error_msg), (
+            f"_AnsibleTaggedStr error should be ignored: {tagged_error_msg}"
+        )
+
+        # Test similar error without _AnsibleTaggedStr is NOT ignored
+        normal_error_msg = 'can only concatenate list (not "int") to list'
+        assert not ignored_re.search(normal_error_msg), (
+            f"Normal error should not be ignored: {normal_error_msg}"
+        )
+
+        # Test that the ignore pattern works for the specific error we're testing
+        assert ignored_re.search(
+            'can only concatenate str (not "_AnsibleTaggedStr") to str'
+        ), "String concatenation with _AnsibleTaggedStr should also be ignored"
